@@ -105,9 +105,10 @@ struct SWindowData {
     CWindowOverridableVar<bool>               renderUnfocused    = false;
     CWindowOverridableVar<bool>               noFollowMouse      = false;
     CWindowOverridableVar<bool>               noScreenShare      = false;
+    CWindowOverridableVar<bool>               noVRR              = false;
 
-    CWindowOverridableVar<Hyprlang::INT>      borderSize = {std::string("general:border_size"), Hyprlang::INT(0), std::nullopt};
-    CWindowOverridableVar<Hyprlang::INT>      rounding   = {std::string("decoration:rounding"), Hyprlang::INT(0), std::nullopt};
+    CWindowOverridableVar<Hyprlang::INT>      borderSize = {std::string("general:border_size"), sc<Hyprlang::INT>(0), std::nullopt};
+    CWindowOverridableVar<Hyprlang::INT>      rounding   = {std::string("decoration:rounding"), sc<Hyprlang::INT>(0), std::nullopt};
 
     CWindowOverridableVar<Hyprlang::FLOAT>    roundingPower  = {std::string("decoration:rounding_power")};
     CWindowOverridableVar<Hyprlang::FLOAT>    scrollMouse    = {std::string("input:scroll_factor")};
@@ -362,6 +363,8 @@ class CWindow {
     int                        getRealBorderSize();
     float                      getScrollMouse();
     float                      getScrollTouchpad();
+    bool                       isScrollMouseOverridden();
+    bool                       isScrollTouchpadOverridden();
     void                       updateWindowData();
     void                       updateWindowData(const struct SWorkspaceRule&);
     void                       onBorderAngleAnimEnd(WP<Hyprutils::Animation::CBaseAnimatedVariable> pav);
@@ -412,6 +415,7 @@ class CWindow {
     std::optional<std::string> xdgDescription();
     PHLWINDOW                  parent();
     bool                       priorityFocus();
+    SP<CWLSurfaceResource>     getSolitaryResource();
 
     CBox                       getWindowMainSurfaceBox() const {
         return {m_realPosition->value().x, m_realPosition->value().y, m_realSize->value().x, m_realSize->value().y};
@@ -488,6 +492,7 @@ namespace NWindowProperties {
         {"opaque", [](const PHLWINDOW& pWindow) { return &pWindow->m_windowData.opaque; }},
         {"forcergbx", [](const PHLWINDOW& pWindow) { return &pWindow->m_windowData.RGBX; }},
         {"syncfullscreen", [](const PHLWINDOW& pWindow) { return &pWindow->m_windowData.syncFullscreen; }},
+        {"novrr", [](const PHLWINDOW& pWindow) { return &pWindow->m_windowData.noVRR; }},
         {"immediate", [](const PHLWINDOW& pWindow) { return &pWindow->m_windowData.tearing; }},
         {"xray", [](const PHLWINDOW& pWindow) { return &pWindow->m_windowData.xray; }},
         {"nofollowmouse", [](const PHLWINDOW& pWindow) { return &pWindow->m_windowData.noFollowMouse; }},
@@ -531,12 +536,12 @@ struct std::formatter<PHLWINDOW, CharT> : std::formatter<CharT> {
     auto format(PHLWINDOW const& w, FormatContext& ctx) const {
         auto&& out = ctx.out();
         if (formatAddressOnly)
-            return std::format_to(out, "{:x}", (uintptr_t)w.get());
+            return std::format_to(out, "{:x}", rc<uintptr_t>(w.get()));
         if (!w)
             return std::format_to(out, "[Window nullptr]");
 
         std::format_to(out, "[");
-        std::format_to(out, "Window {:x}: title: \"{}\"", (uintptr_t)w.get(), w->m_title);
+        std::format_to(out, "Window {:x}: title: \"{}\"", rc<uintptr_t>(w.get()), w->m_title);
         if (formatWorkspace)
             std::format_to(out, ", workspace: {}", w->m_workspace ? w->workspaceID() : WORKSPACE_INVALID);
         if (formatMonitor)
