@@ -24,10 +24,13 @@ enum eKeyboardModifiers {
 class IKeyboard : public IHID {
   public:
     virtual ~IKeyboard();
-    virtual uint32_t                  getCapabilities();
-    virtual eHIDType                  getType();
-    virtual bool                      isVirtual() = 0;
-    virtual SP<Aquamarine::IKeyboard> aq()        = 0;
+    virtual uint32_t   getCapabilities();
+    virtual eHIDType   getType();
+    virtual bool       isVirtual() = 0;
+    virtual wl_client* getClient() {
+        return nullptr;
+    };
+    virtual SP<Aquamarine::IKeyboard> aq() = 0;
 
     struct SKeyEvent {
         uint32_t              timeMs     = 0;
@@ -48,10 +51,10 @@ class IKeyboard : public IHID {
     };
 
     struct {
-        CSignal key;
-        CSignal modifiers;
-        CSignal keymap;
-        CSignal repeatInfo;
+        CSignalT<SKeyEvent>       key;
+        CSignalT<SModifiersEvent> modifiers;
+        CSignalT<SKeymapEvent>    keymap;
+        CSignalT<>                repeatInfo;
     } m_keyboardEvents;
 
     struct SStringRuleNames {
@@ -62,21 +65,27 @@ class IKeyboard : public IHID {
         std::string rules   = "";
     };
 
-    void                    setKeymap(const SStringRuleNames& rules);
-    void                    updateXKBTranslationState(xkb_keymap* const keymap = nullptr);
-    std::string             getActiveLayout();
-    std::optional<uint32_t> getLEDs();
-    void                    updateLEDs();
-    void                    updateLEDs(uint32_t leds);
-    uint32_t                getModifiers();
-    void                    updateModifiers(uint32_t depressed, uint32_t latched, uint32_t locked, uint32_t group);
-    bool                    updateModifiersState(); // rets whether changed
-    void                    updateXkbStateWithKey(uint32_t xkbKey, bool pressed);
-    void                    updateKeymapFD();
+    void                              setKeymap(const SStringRuleNames& rules);
+    void                              updateXKBTranslationState(xkb_keymap* const keymap = nullptr);
+    std::optional<xkb_layout_index_t> getActiveLayoutIndex();
+    std::string                       getActiveLayout();
+    std::optional<uint32_t>           getLEDs();
+    void                              updateLEDs();
+    void                              updateLEDs(uint32_t leds);
+    uint32_t                          getModifiers();
+    void                              updateModifiers(uint32_t depressed, uint32_t latched, uint32_t locked, uint32_t group);
+    bool                              updateModifiersState(); // rets whether changed
+    void                              updateXkbStateWithKey(uint32_t xkbKey, bool pressed);
+    void                              updateKeymapFD();
+    bool                              getPressed(uint32_t key);
+    bool                              shareStates();
 
-    bool                    m_active     = false;
-    bool                    m_enabled    = true;
-    bool                    m_allowBinds = true;
+    bool                              m_active     = false;
+    bool                              m_enabled    = true;
+    bool                              m_allowBinds = true;
+
+    // permission flag: whether this keyboard is allowed to be processed
+    bool m_allowed = true;
 
     // if the keymap is overridden by the implementation,
     // don't try to set keyboard rules anymore, to avoid overwriting the requested one.
@@ -115,5 +124,9 @@ class IKeyboard : public IHID {
   private:
     void                  clearManuallyAllocd();
 
-    std::vector<uint32_t> m_pressedXKB;
+    std::vector<uint32_t> m_pressed;
+
+  protected:
+    bool updatePressed(uint32_t key, bool pressed);
+    bool m_shareStates = true;
 };
